Class: Gjallarhorn::Deployment::Legacy

Inherits:
Strategy
  • Object
show all
Defined in:
lib/gjallarhorn/deployment/legacy.rb

Overview

Legacy deployment strategy

Maintains backward compatibility with the original deployment interface by calling the adapter's deploy method directly. This is used for testing and for adapters that haven't been updated to the new container management interface.

Since:

  • 0.1.0

Instance Attribute Summary

Attributes inherited from Strategy

#adapter, #logger, #proxy_manager

Instance Method Summary collapse

Methods inherited from Strategy

#initialize, #name

Constructor Details

This class inherits a constructor from Gjallarhorn::Deployment::Strategy

Instance Method Details

#deploy(image:, environment:, services:) ⇒ void

This method returns an undefined value.

Deploy services using legacy adapter interface

Since:

  • 0.1.0



22
23
24
25
26
27
28
29
30
# File 'lib/gjallarhorn/deployment/legacy.rb', line 22

def deploy(image:, environment:, services:)
  @logger.info "Using legacy deployment interface"

  @adapter.deploy(
    image: image,
    environment: environment,
    services: services
  )
end

#zero_downtime?Boolean

Check if strategy supports zero-downtime deployments

Since:

  • 0.1.0



35
36
37
# File 'lib/gjallarhorn/deployment/legacy.rb', line 35

def zero_downtime?
  false
end