Module: Gjallarhorn Abstract
- Defined in:
- lib/gjallarhorn.rb,
lib/gjallarhorn/cli.rb,
lib/gjallarhorn/history.rb,
lib/gjallarhorn/version.rb,
lib/gjallarhorn/deployer.rb,
lib/gjallarhorn/adapter/aws.rb,
lib/gjallarhorn/adapter/base.rb,
lib/gjallarhorn/configuration.rb,
lib/gjallarhorn/proxy/manager.rb,
lib/gjallarhorn/deployment/basic.rb,
lib/gjallarhorn/deployment/legacy.rb,
lib/gjallarhorn/deployment/strategy.rb,
lib/gjallarhorn/proxy/nginx_manager.rb,
lib/gjallarhorn/proxy/traefik_manager.rb,
lib/gjallarhorn/deployment/zero_downtime.rb,
lib/gjallarhorn/proxy/kamal_proxy_manager.rb
Overview
This module is abstract.
Subclass and override #deploy, #rollback, #status, #health_check, #scale, and #logs to implement a cloud provider adapter.
Base adapter interface for cloud provider implementations
The Base class defines the common interface that all cloud provider adapters must implement. It provides the foundation for deploying, managing, and monitoring containerized applications across different cloud platforms.
Defined Under Namespace
Modules: Adapter, Deployment, Proxy Classes: CLI, Configuration, ConfigurationError, Deployer, DeploymentError, Error, History
Constant Summary collapse
- VERSION =
"0.1.0"